SET @OLD_UNIQUE_CHECKS=@@UNIQUE_CHECKS, UNIQUE_CHECKS=0;
SET @OLD_FOREIGN_KEY_CHECKS=@@FOREIGN_KEY_CHECKS, FOREIGN_KEY_CHECKS=0;
SET @OLD_SQL_MODE=@@SQL_MODE, SQL_MODE='TRADITIONAL';


-- -----------------------------------------------------
-- Table `agent_builds`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `agent_builds` (
  `created_at` DATETIME NULL DEFAULT NULL ,
  `updated_at` DATETIME NULL DEFAULT NULL ,
  `deleted_at` DATETIME NULL DEFAULT NULL ,
  `deleted` TINYINT(1) NULL DEFAULT NULL ,
  `id` INT(11) NOT NULL AUTO_INCREMENT ,
  `hypervisor` VARCHAR(255) NULL DEFAULT NULL ,
  `os` VARCHAR(255) NULL DEFAULT NULL ,
  `architecture` VARCHAR(255) NULL DEFAULT NULL ,
  `version` VARCHAR(255) NULL DEFAULT NULL ,
  `url` VARCHAR(255) NULL DEFAULT NULL ,
  `md5hash` VARCHAR(255) NULL DEFAULT NULL ,
  PRIMARY KEY (`id`) )
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `aggregates`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `aggregates` (
  `created_at` DATETIME NULL DEFAULT NULL ,
  `updated_at` DATETIME NULL DEFAULT NULL ,
  `deleted_at` DATETIME NULL DEFAULT NULL ,
  `deleted` TINYINT(1) NULL DEFAULT NULL ,
  `id` INT(11) NOT NULL AUTO_INCREMENT ,
  `name` VARCHAR(255) NULL DEFAULT NULL ,
  `operational_state` VARCHAR(255) NOT NULL ,
  `availability_zone` VARCHAR(255) NOT NULL ,
  PRIMARY KEY (`id`) ,
  UNIQUE INDEX `name` (`name` ASC) )
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `aggregate_hosts`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `aggregate_hosts` (
  `created_at` DATETIME NULL DEFAULT NULL ,
  `updated_at` DATETIME NULL DEFAULT NULL ,
  `deleted_at` DATETIME NULL DEFAULT NULL ,
  `deleted` TINYINT(1) NULL DEFAULT NULL ,
  `id` INT(11) NOT NULL AUTO_INCREMENT ,
  `host` VARCHAR(255) NULL DEFAULT NULL ,
  `aggregate_id` INT(11) NOT NULL ,
  PRIMARY KEY (`id`) ,
  UNIQUE INDEX `host` (`host` ASC) ,
  INDEX `aggregate_id` (`aggregate_id` ASC) ,
  CONSTRAINT `aggregate_hosts_ibfk_1`
    FOREIGN KEY (`aggregate_id` )
    REFERENCES `aggregates` (`id` ))
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `aggregate_metadata`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `aggregate_metadata` (
  `created_at` DATETIME NULL DEFAULT NULL ,
  `updated_at` DATETIME NULL DEFAULT NULL ,
  `deleted_at` DATETIME NULL DEFAULT NULL ,
  `deleted` TINYINT(1) NULL DEFAULT NULL ,
  `id` INT(11) NOT NULL AUTO_INCREMENT ,
  `aggregate_id` INT(11) NOT NULL ,
  `key` VARCHAR(255) NOT NULL ,
  `value` VARCHAR(255) NOT NULL ,
  PRIMARY KEY (`id`) ,
  INDEX `aggregate_id` (`aggregate_id` ASC) ,
  CONSTRAINT `aggregate_metadata_ibfk_1`
    FOREIGN KEY (`aggregate_id` )
    REFERENCES `aggregates` (`id` ))
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `auth_tokens`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `auth_tokens` (
  `created_at` DATETIME NULL DEFAULT NULL ,
  `updated_at` DATETIME NULL DEFAULT NULL ,
  `deleted_at` DATETIME NULL DEFAULT NULL ,
  `deleted` TINYINT(1) NULL DEFAULT NULL ,
  `token_hash` VARCHAR(255) NOT NULL ,
  `user_id` VARCHAR(255) NULL DEFAULT NULL ,
  `server_management_url` VARCHAR(255) NULL DEFAULT NULL ,
  `storage_url` VARCHAR(255) NULL DEFAULT NULL ,
  `cdn_management_url` VARCHAR(255) NULL DEFAULT NULL ,
  PRIMARY KEY (`token_hash`) )
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `instances`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `instances` (
  `created_at` DATETIME NULL DEFAULT NULL ,
  `updated_at` DATETIME NULL DEFAULT NULL ,
  `deleted_at` DATETIME NULL DEFAULT NULL ,
  `deleted` TINYINT(1) NULL DEFAULT NULL ,
  `id` INT(11) NOT NULL AUTO_INCREMENT ,
  `internal_id` INT(11) NULL DEFAULT NULL ,
  `user_id` VARCHAR(255) NULL DEFAULT NULL ,
  `project_id` VARCHAR(255) NULL DEFAULT NULL ,
  `image_ref` VARCHAR(255) NULL DEFAULT NULL ,
  `kernel_id` VARCHAR(255) NULL DEFAULT NULL ,
  `ramdisk_id` VARCHAR(255) NULL DEFAULT NULL ,
  `server_name` VARCHAR(255) NULL DEFAULT NULL ,
  `launch_index` INT(11) NULL DEFAULT NULL ,
  `key_name` VARCHAR(255) NULL DEFAULT NULL ,
  `key_data` MEDIUMTEXT NULL DEFAULT NULL ,
  `power_state` INT(11) NULL DEFAULT NULL ,
  `vm_state` VARCHAR(255) NULL DEFAULT NULL ,
  `memory_mb` INT(11) NULL DEFAULT NULL ,
  `vcpus` INT(11) NULL DEFAULT NULL ,
  `hostname` VARCHAR(255) NULL DEFAULT NULL ,
  `host` VARCHAR(255) NULL DEFAULT NULL ,
  `user_data` MEDIUMTEXT NULL DEFAULT NULL ,
  `reservation_id` VARCHAR(255) NULL DEFAULT NULL ,
  `scheduled_at` DATETIME NULL DEFAULT NULL ,
  `launched_at` DATETIME NULL DEFAULT NULL ,
  `terminated_at` DATETIME NULL DEFAULT NULL ,
  `display_name` VARCHAR(255) NULL DEFAULT NULL ,
  `display_description` VARCHAR(255) NULL DEFAULT NULL ,
  `availability_zone` VARCHAR(255) NULL DEFAULT NULL ,
  `locked` TINYINT(1) NULL DEFAULT NULL ,
  `os_type` VARCHAR(255) NULL DEFAULT NULL ,
  `launched_on` MEDIUMTEXT NULL DEFAULT NULL ,
  `instance_type_id` INT(11) NULL DEFAULT NULL ,
  `vm_mode` VARCHAR(255) NULL DEFAULT NULL ,
  `uuid` VARCHAR(36) NULL DEFAULT NULL ,
  `architecture` VARCHAR(255) NULL DEFAULT NULL ,
  `root_device_name` VARCHAR(255) NULL DEFAULT NULL ,
  `access_ip_v4` VARCHAR(255) NULL DEFAULT NULL ,
  `access_ip_v6` VARCHAR(255) NULL DEFAULT NULL ,
  `config_drive` VARCHAR(255) NULL DEFAULT NULL ,
  `task_state` VARCHAR(255) NULL DEFAULT NULL ,
  `default_ephemeral_device` VARCHAR(255) NULL DEFAULT NULL ,
  `default_swap_device` VARCHAR(255) NULL DEFAULT NULL ,
  `progress` INT(11) NULL DEFAULT NULL ,
  `auto_disk_config` TINYINT(1) NULL DEFAULT NULL ,
  `shutdown_terminate` TINYINT(1) NULL DEFAULT NULL ,
  `disable_terminate` TINYINT(1) NULL DEFAULT NULL ,
  `root_gb` INT(11) NULL DEFAULT NULL ,
  `ephemeral_gb` INT(11) NULL DEFAULT NULL ,
  `cell_name` VARCHAR(255) NULL DEFAULT NULL ,
  PRIMARY KEY (`id`) ,
  UNIQUE INDEX `uuid` (`uuid` ASC) ,
  INDEX `project_id` (`project_id` ASC) )
ENGINE = InnoDB
AUTO_INCREMENT = 2
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `snapshots`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `snapshots` (
  `created_at` DATETIME NULL DEFAULT NULL ,
  `updated_at` DATETIME NULL DEFAULT NULL ,
  `deleted_at` DATETIME NULL DEFAULT NULL ,
  `deleted` TINYINT(1) NULL DEFAULT NULL ,
  `id` INT(11) NOT NULL AUTO_INCREMENT ,
  `volume_id` INT(11) NOT NULL ,
  `user_id` VARCHAR(255) NULL DEFAULT NULL ,
  `project_id` VARCHAR(255) NULL DEFAULT NULL ,
  `status` VARCHAR(255) NULL DEFAULT NULL ,
  `progress` VARCHAR(255) NULL DEFAULT NULL ,
  `volume_size` INT(11) NULL DEFAULT NULL ,
  `scheduled_at` DATETIME NULL DEFAULT NULL ,
  `display_name` VARCHAR(255) NULL DEFAULT NULL ,
  `display_description` VARCHAR(255) NULL DEFAULT NULL ,
  PRIMARY KEY (`id`) )
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `volumes`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `volumes` (
  `created_at` DATETIME NULL DEFAULT NULL ,
  `updated_at` DATETIME NULL DEFAULT NULL ,
  `deleted_at` DATETIME NULL DEFAULT NULL ,
  `deleted` TINYINT(1) NULL DEFAULT NULL ,
  `id` INT(11) NOT NULL AUTO_INCREMENT ,
  `ec2_id` VARCHAR(255) NULL DEFAULT NULL ,
  `user_id` VARCHAR(255) NULL DEFAULT NULL ,
  `project_id` VARCHAR(255) NULL DEFAULT NULL ,
  `host` VARCHAR(255) NULL DEFAULT NULL ,
  `size` INT(11) NULL DEFAULT NULL ,
  `availability_zone` VARCHAR(255) NULL DEFAULT NULL ,
  `instance_id` INT(11) NULL DEFAULT NULL ,
  `mountpoint` VARCHAR(255) NULL DEFAULT NULL ,
  `attach_time` VARCHAR(255) NULL DEFAULT NULL ,
  `status` VARCHAR(255) NULL DEFAULT NULL ,
  `attach_status` VARCHAR(255) NULL DEFAULT NULL ,
  `scheduled_at` DATETIME NULL DEFAULT NULL ,
  `launched_at` DATETIME NULL DEFAULT NULL ,
  `terminated_at` DATETIME NULL DEFAULT NULL ,
  `display_name` VARCHAR(255) NULL DEFAULT NULL ,
  `display_description` VARCHAR(255) NULL DEFAULT NULL ,
  `provider_location` VARCHAR(256) NULL DEFAULT NULL ,
  `provider_auth` VARCHAR(256) NULL DEFAULT NULL ,
  `snapshot_id` INT(11) NULL DEFAULT NULL ,
  `volume_type_id` INT(11) NULL DEFAULT NULL ,
  PRIMARY KEY (`id`) ,
  INDEX `instance_id` (`instance_id` ASC) ,
  CONSTRAINT `volumes_ibfk_1`
    FOREIGN KEY (`instance_id` )
    REFERENCES `instances` (`id` ))
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `block_device_mapping`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `block_device_mapping` (
  `created_at` DATETIME NULL DEFAULT NULL ,
  `updated_at` DATETIME NULL DEFAULT NULL ,
  `deleted_at` DATETIME NULL DEFAULT NULL ,
  `deleted` TINYINT(1) NULL DEFAULT NULL ,
  `id` INT(11) NOT NULL AUTO_INCREMENT ,
  `instance_id` INT(11) NOT NULL ,
  `device_name` VARCHAR(255) NOT NULL ,
  `delete_on_termination` TINYINT(1) NULL DEFAULT NULL ,
  `virtual_name` VARCHAR(255) NULL DEFAULT NULL ,
  `snapshot_id` INT(11) NULL DEFAULT NULL ,
  `volume_id` INT(11) NULL DEFAULT NULL ,
  `volume_size` INT(11) NULL DEFAULT NULL ,
  `no_device` TINYINT(1) NULL DEFAULT NULL ,
  `connection_info` MEDIUMTEXT NULL DEFAULT NULL ,
  PRIMARY KEY (`id`) ,
  INDEX `instance_id` (`instance_id` ASC) ,
  INDEX `snapshot_id` (`snapshot_id` ASC) ,
  INDEX `volume_id` (`volume_id` ASC) ,
  CONSTRAINT `block_device_mapping_ibfk_1`
    FOREIGN KEY (`instance_id` )
    REFERENCES `instances` (`id` ),
  CONSTRAINT `block_device_mapping_ibfk_2`
    FOREIGN KEY (`snapshot_id` )
    REFERENCES `snapshots` (`id` ),
  CONSTRAINT `block_device_mapping_ibfk_3`
    FOREIGN KEY (`volume_id` )
    REFERENCES `volumes` (`id` ))
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `bw_usage_cache`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `bw_usage_cache` (
  `created_at` DATETIME NULL DEFAULT NULL ,
  `updated_at` DATETIME NULL DEFAULT NULL ,
  `deleted_at` DATETIME NULL DEFAULT NULL ,
  `deleted` TINYINT(1) NULL DEFAULT NULL ,
  `id` INT(11) NOT NULL AUTO_INCREMENT ,
  `start_period` DATETIME NOT NULL ,
  `last_refreshed` DATETIME NULL DEFAULT NULL ,
  `bw_in` BIGINT(20) NULL DEFAULT NULL ,
  `bw_out` BIGINT(20) NULL DEFAULT NULL ,
  `mac` VARCHAR(255) NULL DEFAULT NULL ,
  PRIMARY KEY (`id`) )
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `cells`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `cells` (
  `created_at` DATETIME NULL DEFAULT NULL ,
  `updated_at` DATETIME NULL DEFAULT NULL ,
  `deleted_at` DATETIME NULL DEFAULT NULL ,
  `deleted` TINYINT(1) NULL DEFAULT NULL ,
  `id` INT(11) NOT NULL AUTO_INCREMENT ,
  `api_url` VARCHAR(255) NULL DEFAULT NULL ,
  `username` VARCHAR(255) NULL DEFAULT NULL ,
  `password` VARCHAR(255) NULL DEFAULT NULL ,
  `weight_offset` FLOAT NULL DEFAULT NULL ,
  `weight_scale` FLOAT NULL DEFAULT NULL ,
  `name` VARCHAR(255) NULL DEFAULT NULL ,
  `is_parent` TINYINT(1) NULL DEFAULT NULL ,
  `rpc_host` VARCHAR(255) NULL DEFAULT NULL ,
  `rpc_port` INT(11) NULL DEFAULT NULL ,
  `rpc_virtual_host` VARCHAR(255) NULL DEFAULT NULL ,
  PRIMARY KEY (`id`) )
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `certificates`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `certificates` (
  `created_at` DATETIME NULL DEFAULT NULL ,
  `updated_at` DATETIME NULL DEFAULT NULL ,
  `deleted_at` DATETIME NULL DEFAULT NULL ,
  `deleted` TINYINT(1) NULL DEFAULT NULL ,
  `id` INT(11) NOT NULL AUTO_INCREMENT ,
  `user_id` VARCHAR(255) NULL DEFAULT NULL ,
  `project_id` VARCHAR(255) NULL DEFAULT NULL ,
  `file_name` VARCHAR(255) NULL DEFAULT NULL ,
  PRIMARY KEY (`id`) )
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `compute_nodes`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `compute_nodes` (
  `created_at` DATETIME NULL DEFAULT NULL ,
  `updated_at` DATETIME NULL DEFAULT NULL ,
  `deleted_at` DATETIME NULL DEFAULT NULL ,
  `deleted` TINYINT(1) NULL DEFAULT NULL ,
  `id` INT(11) NOT NULL AUTO_INCREMENT ,
  `service_id` INT(11) NOT NULL ,
  `vcpus` INT(11) NOT NULL ,
  `memory_mb` INT(11) NOT NULL ,
  `local_gb` INT(11) NOT NULL ,
  `vcpus_used` INT(11) NOT NULL ,
  `memory_mb_used` INT(11) NOT NULL ,
  `local_gb_used` INT(11) NOT NULL ,
  `hypervisor_type` MEDIUMTEXT NOT NULL ,
  `hypervisor_version` INT(11) NOT NULL ,
  `cpu_info` MEDIUMTEXT NOT NULL ,
  `disk_available_least` INT(11) NULL DEFAULT NULL ,
  `free_ram_mb` INT(11) NULL DEFAULT NULL ,
  `free_disk_gb` INT(11) NULL DEFAULT NULL ,
  `current_workload` INT(11) NULL DEFAULT NULL ,
  `running_vms` INT(11) NULL DEFAULT NULL ,
  `hypervisor_hostname` VARCHAR(255) NULL DEFAULT NULL ,
  PRIMARY KEY (`id`) )
ENGINE = InnoDB
AUTO_INCREMENT = 6
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `console_pools`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `console_pools` (
  `created_at` DATETIME NULL DEFAULT NULL ,
  `updated_at` DATETIME NULL DEFAULT NULL ,
  `deleted_at` DATETIME NULL DEFAULT NULL ,
  `deleted` TINYINT(1) NULL DEFAULT NULL ,
  `id` INT(11) NOT NULL AUTO_INCREMENT ,
  `address` VARCHAR(255) NULL DEFAULT NULL ,
  `username` VARCHAR(255) NULL DEFAULT NULL ,
  `password` VARCHAR(255) NULL DEFAULT NULL ,
  `console_type` VARCHAR(255) NULL DEFAULT NULL ,
  `public_hostname` VARCHAR(255) NULL DEFAULT NULL ,
  `host` VARCHAR(255) NULL DEFAULT NULL ,
  `compute_host` VARCHAR(255) NULL DEFAULT NULL ,
  PRIMARY KEY (`id`) )
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `consoles`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `consoles` (
  `created_at` DATETIME NULL DEFAULT NULL ,
  `updated_at` DATETIME NULL DEFAULT NULL ,
  `deleted_at` DATETIME NULL DEFAULT NULL ,
  `deleted` TINYINT(1) NULL DEFAULT NULL ,
  `id` INT(11) NOT NULL AUTO_INCREMENT ,
  `instance_name` VARCHAR(255) NULL DEFAULT NULL ,
  `instance_id` INT(11) NULL DEFAULT NULL ,
  `password` VARCHAR(255) NULL DEFAULT NULL ,
  `port` INT(11) NULL DEFAULT NULL ,
  `pool_id` INT(11) NULL DEFAULT NULL ,
  PRIMARY KEY (`id`) ,
  INDEX `pool_id` (`pool_id` ASC) ,
  CONSTRAINT `consoles_ibfk_1`
    FOREIGN KEY (`pool_id` )
    REFERENCES `console_pools` (`id` ))
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `dns_domains`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `dns_domains` (
  `created_at` DATETIME NULL DEFAULT NULL ,
  `updated_at` DATETIME NULL DEFAULT NULL ,
  `deleted_at` DATETIME NULL DEFAULT NULL ,
  `deleted` TINYINT(1) NULL DEFAULT NULL ,
  `domain` VARCHAR(512) NOT NULL ,
  `scope` VARCHAR(255) NULL DEFAULT NULL ,
  `availability_zone` VARCHAR(255) NULL DEFAULT NULL ,
  `project_id` VARCHAR(255) NULL DEFAULT NULL ,
  PRIMARY KEY (`domain`) ,
  INDEX `project_id` (`project_id` ASC) ,
  CONSTRAINT `dns_domains_ibfk_1`
    FOREIGN KEY (`project_id` )
    REFERENCES `projects` (`id` ))
ENGINE = InnoDB
DEFAULT CHARACTER SET = latin1;


-- -----------------------------------------------------
-- Table `fixed_ips`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `fixed_ips` (
  `created_at` DATETIME NULL DEFAULT NULL ,
  `updated_at` DATETIME NULL DEFAULT NULL ,
  `deleted_at` DATETIME NULL DEFAULT NULL ,
  `deleted` TINYINT(1) NULL DEFAULT NULL ,
  `id` INT(11) NOT NULL AUTO_INCREMENT ,
  `address` VARCHAR(255) NULL DEFAULT NULL ,
  `network_id` INT(11) NULL DEFAULT NULL ,
  `instance_id` INT(11) NULL DEFAULT NULL ,
  `allocated` TINYINT(1) NULL DEFAULT NULL ,
  `leased` TINYINT(1) NULL DEFAULT NULL ,
  `reserved` TINYINT(1) NULL DEFAULT NULL ,
  `virtual_interface_id` INT(11) NULL DEFAULT NULL ,
  `host` VARCHAR(255) NULL DEFAULT NULL ,
  PRIMARY KEY (`id`) ,
  INDEX `network_id` (`network_id` ASC) ,
  INDEX `instance_id` (`instance_id` ASC) ,
  INDEX `fixed_ips_virtual_interface_id_fkey` (`virtual_interface_id` ASC) )
ENGINE = InnoDB
AUTO_INCREMENT = 6145
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `floating_ips`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `floating_ips` (
  `created_at` DATETIME NULL DEFAULT NULL ,
  `updated_at` DATETIME NULL DEFAULT NULL ,
  `deleted_at` DATETIME NULL DEFAULT NULL ,
  `deleted` TINYINT(1) NULL DEFAULT NULL ,
  `id` INT(11) NOT NULL AUTO_INCREMENT ,
  `address` VARCHAR(255) NULL DEFAULT NULL ,
  `fixed_ip_id` INT(11) NULL DEFAULT NULL ,
  `project_id` VARCHAR(255) NULL DEFAULT NULL ,
  `host` VARCHAR(255) NULL DEFAULT NULL ,
  `auto_assigned` TINYINT(1) NULL DEFAULT NULL ,
  `pool` VARCHAR(255) NULL DEFAULT NULL ,
  `interface` VARCHAR(255) NULL DEFAULT NULL ,
  PRIMARY KEY (`id`) ,
  INDEX `fixed_ip_id` (`fixed_ip_id` ASC) )
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `instance_actions`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `instance_actions` (
  `created_at` DATETIME NULL DEFAULT NULL ,
  `updated_at` DATETIME NULL DEFAULT NULL ,
  `deleted_at` DATETIME NULL DEFAULT NULL ,
  `deleted` TINYINT(1) NULL DEFAULT NULL ,
  `id` INT(11) NOT NULL AUTO_INCREMENT ,
  `action` VARCHAR(255) NULL DEFAULT NULL ,
  `error` MEDIUMTEXT NULL DEFAULT NULL ,
  `instance_uuid` VARCHAR(36) NULL DEFAULT NULL ,
  PRIMARY KEY (`id`) )
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `instance_faults`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `instance_faults` (
  `created_at` DATETIME NULL DEFAULT NULL ,
  `updated_at` DATETIME NULL DEFAULT NULL ,
  `deleted_at` DATETIME NULL DEFAULT NULL ,
  `deleted` TINYINT(1) NULL DEFAULT NULL ,
  `id` INT(11) NOT NULL AUTO_INCREMENT ,
  `instance_uuid` VARCHAR(36) NULL DEFAULT NULL ,
  `code` INT(11) NOT NULL ,
  `message` VARCHAR(255) NULL DEFAULT NULL ,
  `details` MEDIUMTEXT NULL DEFAULT NULL ,
  PRIMARY KEY (`id`) )
ENGINE = InnoDB
AUTO_INCREMENT = 7
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `instance_info_caches`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `instance_info_caches` (
  `created_at` DATETIME NULL DEFAULT NULL ,
  `updated_at` DATETIME NULL DEFAULT NULL ,
  `deleted_at` DATETIME NULL DEFAULT NULL ,
  `deleted` TINYINT(1) NULL DEFAULT NULL ,
  `id` INT(11) NOT NULL AUTO_INCREMENT ,
  `network_info` MEDIUMTEXT NULL DEFAULT NULL ,
  `instance_id` VARCHAR(36) NOT NULL ,
  PRIMARY KEY (`id`) ,
  UNIQUE INDEX `instance_id` (`instance_id` ASC) ,
  CONSTRAINT `instance_info_caches_ibfk_1`
    FOREIGN KEY (`instance_id` )
    REFERENCES `instances` (`uuid` ))
ENGINE = InnoDB
AUTO_INCREMENT = 2
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `instance_metadata`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `instance_metadata` (
  `created_at` DATETIME NULL DEFAULT NULL ,
  `updated_at` DATETIME NULL DEFAULT NULL ,
  `deleted_at` DATETIME NULL DEFAULT NULL ,
  `deleted` TINYINT(1) NULL DEFAULT NULL ,
  `id` INT(11) NOT NULL AUTO_INCREMENT ,
  `instance_id` INT(11) NOT NULL ,
  `key` VARCHAR(255) NULL DEFAULT NULL ,
  `value` VARCHAR(255) NULL DEFAULT NULL ,
  PRIMARY KEY (`id`) ,
  INDEX `instance_id` (`instance_id` ASC) ,
  CONSTRAINT `instance_metadata_ibfk_1`
    FOREIGN KEY (`instance_id` )
    REFERENCES `instances` (`id` ))
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `instance_types`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `instance_types` (
  `created_at` DATETIME NULL DEFAULT NULL ,
  `updated_at` DATETIME NULL DEFAULT NULL ,
  `deleted_at` DATETIME NULL DEFAULT NULL ,
  `deleted` TINYINT(1) NULL DEFAULT NULL ,
  `name` VARCHAR(255) NULL DEFAULT NULL ,
  `id` INT(11) NOT NULL AUTO_INCREMENT ,
  `memory_mb` INT(11) NOT NULL ,
  `vcpus` INT(11) NOT NULL ,
  `swap` INT(11) NOT NULL ,
  `vcpu_weight` INT(11) NULL DEFAULT NULL ,
  `flavorid` VARCHAR(255) NULL DEFAULT NULL ,
  `rxtx_factor` FLOAT NULL DEFAULT NULL ,
  `root_gb` INT(11) NULL DEFAULT NULL ,
  `ephemeral_gb` INT(11) NULL DEFAULT NULL ,
  PRIMARY KEY (`id`) )
ENGINE = InnoDB
AUTO_INCREMENT = 6
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `instance_type_extra_specs`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `instance_type_extra_specs` (
  `created_at` DATETIME NULL DEFAULT NULL ,
  `updated_at` DATETIME NULL DEFAULT NULL ,
  `deleted_at` DATETIME NULL DEFAULT NULL ,
  `deleted` TINYINT(1) NULL DEFAULT NULL ,
  `id` INT(11) NOT NULL AUTO_INCREMENT ,
  `instance_type_id` INT(11) NOT NULL ,
  `key` VARCHAR(255) NULL DEFAULT NULL ,
  `value` VARCHAR(255) NULL DEFAULT NULL ,
  PRIMARY KEY (`id`) ,
  INDEX `instance_type_id` (`instance_type_id` ASC) ,
  CONSTRAINT `instance_type_extra_specs_ibfk_1`
    FOREIGN KEY (`instance_type_id` )
    REFERENCES `instance_types` (`id` ))
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `iscsi_targets`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `iscsi_targets` (
  `created_at` DATETIME NULL DEFAULT NULL ,
  `updated_at` DATETIME NULL DEFAULT NULL ,
  `deleted_at` DATETIME NULL DEFAULT NULL ,
  `deleted` TINYINT(1) NULL DEFAULT NULL ,
  `id` INT(11) NOT NULL AUTO_INCREMENT ,
  `target_num` INT(11) NULL DEFAULT NULL ,
  `host` VARCHAR(255) NULL DEFAULT NULL ,
  `volume_id` INT(11) NULL DEFAULT NULL ,
  PRIMARY KEY (`id`) ,
  INDEX `volume_id` (`volume_id` ASC) ,
  CONSTRAINT `iscsi_targets_ibfk_1`
    FOREIGN KEY (`volume_id` )
    REFERENCES `volumes` (`id` ))
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `key_pairs`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `key_pairs` (
  `created_at` DATETIME NULL DEFAULT NULL ,
  `updated_at` DATETIME NULL DEFAULT NULL ,
  `deleted_at` DATETIME NULL DEFAULT NULL ,
  `deleted` TINYINT(1) NULL DEFAULT NULL ,
  `id` INT(11) NOT NULL AUTO_INCREMENT ,
  `name` VARCHAR(255) NULL DEFAULT NULL ,
  `user_id` VARCHAR(255) NULL DEFAULT NULL ,
  `fingerprint` VARCHAR(255) NULL DEFAULT NULL ,
  `public_key` MEDIUMTEXT NULL DEFAULT NULL ,
  PRIMARY KEY (`id`) )
ENGINE = InnoDB
AUTO_INCREMENT = 3
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `migrate_version`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `migrate_version` (
  `repository_id` VARCHAR(250) NOT NULL ,
  `repository_path` MEDIUMTEXT NULL DEFAULT NULL ,
  `version` INT(11) NULL DEFAULT NULL ,
  PRIMARY KEY (`repository_id`) )
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `migrations`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `migrations` (
  `created_at` DATETIME NULL DEFAULT NULL ,
  `updated_at` DATETIME NULL DEFAULT NULL ,
  `deleted_at` DATETIME NULL DEFAULT NULL ,
  `deleted` TINYINT(1) NULL DEFAULT NULL ,
  `id` INT(11) NOT NULL AUTO_INCREMENT ,
  `source_compute` VARCHAR(255) NULL DEFAULT NULL ,
  `dest_compute` VARCHAR(255) NULL DEFAULT NULL ,
  `dest_host` VARCHAR(255) NULL DEFAULT NULL ,
  `status` VARCHAR(255) NULL DEFAULT NULL ,
  `instance_uuid` VARCHAR(255) NULL DEFAULT NULL ,
  `old_instance_type_id` INT(11) NULL DEFAULT NULL ,
  `new_instance_type_id` INT(11) NULL DEFAULT NULL ,
  PRIMARY KEY (`id`) )
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `networks`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `networks` (
  `created_at` DATETIME NULL DEFAULT NULL ,
  `updated_at` DATETIME NULL DEFAULT NULL ,
  `deleted_at` DATETIME NULL DEFAULT NULL ,
  `deleted` TINYINT(1) NULL DEFAULT NULL ,
  `id` INT(11) NOT NULL AUTO_INCREMENT ,
  `injected` TINYINT(1) NULL DEFAULT NULL ,
  `cidr` VARCHAR(255) NULL DEFAULT NULL ,
  `netmask` VARCHAR(255) NULL DEFAULT NULL ,
  `bridge` VARCHAR(255) NULL DEFAULT NULL ,
  `gateway` VARCHAR(255) NULL DEFAULT NULL ,
  `broadcast` VARCHAR(255) NULL DEFAULT NULL ,
  `dns1` VARCHAR(255) NULL DEFAULT NULL ,
  `vlan` INT(11) NULL DEFAULT NULL ,
  `vpn_public_address` VARCHAR(255) NULL DEFAULT NULL ,
  `vpn_public_port` INT(11) NULL DEFAULT NULL ,
  `vpn_private_address` VARCHAR(255) NULL DEFAULT NULL ,
  `dhcp_start` VARCHAR(255) NULL DEFAULT NULL ,
  `project_id` VARCHAR(255) NULL DEFAULT NULL ,
  `host` VARCHAR(255) NULL DEFAULT NULL ,
  `cidr_v6` VARCHAR(255) NULL DEFAULT NULL ,
  `gateway_v6` VARCHAR(255) NULL DEFAULT NULL ,
  `label` VARCHAR(255) NULL DEFAULT NULL ,
  `netmask_v6` VARCHAR(255) NULL DEFAULT NULL ,
  `bridge_interface` VARCHAR(255) NULL DEFAULT NULL ,
  `multi_host` TINYINT(1) NULL DEFAULT NULL ,
  `dns2` VARCHAR(255) NULL DEFAULT NULL ,
  `uuid` VARCHAR(36) NULL DEFAULT NULL ,
  `priority` INT(11) NULL DEFAULT NULL ,
  `rxtx_base` INT(11) NULL DEFAULT NULL ,
  PRIMARY KEY (`id`) )
ENGINE = InnoDB
AUTO_INCREMENT = 5
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `provider_fw_rules`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `provider_fw_rules` (
  `created_at` DATETIME NULL DEFAULT NULL ,
  `updated_at` DATETIME NULL DEFAULT NULL ,
  `deleted_at` DATETIME NULL DEFAULT NULL ,
  `deleted` TINYINT(1) NULL DEFAULT NULL ,
  `id` INT(11) NOT NULL AUTO_INCREMENT ,
  `protocol` VARCHAR(5) NULL DEFAULT NULL ,
  `from_port` INT(11) NULL DEFAULT NULL ,
  `to_port` INT(11) NULL DEFAULT NULL ,
  `cidr` VARCHAR(255) NULL DEFAULT NULL ,
  PRIMARY KEY (`id`) )
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `quotas`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `quotas` (
  `id` INT(11) NOT NULL AUTO_INCREMENT ,
  `created_at` DATETIME NULL DEFAULT NULL ,
  `updated_at` DATETIME NULL DEFAULT NULL ,
  `deleted_at` DATETIME NULL DEFAULT NULL ,
  `deleted` TINYINT(1) NULL DEFAULT NULL ,
  `project_id` VARCHAR(255) NULL DEFAULT NULL ,
  `resource` VARCHAR(255) NOT NULL ,
  `hard_limit` INT(11) NULL DEFAULT NULL ,
  PRIMARY KEY (`id`) )
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `s3_images`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `s3_images` (
  `created_at` DATETIME NULL DEFAULT NULL ,
  `updated_at` DATETIME NULL DEFAULT NULL ,
  `deleted_at` DATETIME NULL DEFAULT NULL ,
  `deleted` TINYINT(1) NULL DEFAULT NULL ,
  `id` INT(11) NOT NULL AUTO_INCREMENT ,
  `uuid` VARCHAR(36) NOT NULL ,
  PRIMARY KEY (`id`) )
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `security_groups`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `security_groups` (
  `created_at` DATETIME NULL DEFAULT NULL ,
  `updated_at` DATETIME NULL DEFAULT NULL ,
  `deleted_at` DATETIME NULL DEFAULT NULL ,
  `deleted` TINYINT(1) NULL DEFAULT NULL ,
  `id` INT(11) NOT NULL AUTO_INCREMENT ,
  `name` VARCHAR(255) NULL DEFAULT NULL ,
  `description` VARCHAR(255) NULL DEFAULT NULL ,
  `user_id` VARCHAR(255) NULL DEFAULT NULL ,
  `project_id` VARCHAR(255) NULL DEFAULT NULL ,
  PRIMARY KEY (`id`) )
ENGINE = InnoDB
AUTO_INCREMENT = 2
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `security_group_instance_association`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `security_group_instance_association` (
  `created_at` DATETIME NULL DEFAULT NULL ,
  `updated_at` DATETIME NULL DEFAULT NULL ,
  `deleted_at` DATETIME NULL DEFAULT NULL ,
  `deleted` TINYINT(1) NULL DEFAULT NULL ,
  `id` INT(11) NOT NULL AUTO_INCREMENT ,
  `security_group_id` INT(11) NULL DEFAULT NULL ,
  `instance_id` INT(11) NULL DEFAULT NULL ,
  PRIMARY KEY (`id`) ,
  INDEX `security_group_id` (`security_group_id` ASC) ,
  INDEX `instance_id` (`instance_id` ASC) ,
  CONSTRAINT `security_group_instance_association_ibfk_1`
    FOREIGN KEY (`security_group_id` )
    REFERENCES `security_groups` (`id` ),
  CONSTRAINT `security_group_instance_association_ibfk_2`
    FOREIGN KEY (`instance_id` )
    REFERENCES `instances` (`id` ))
ENGINE = InnoDB
AUTO_INCREMENT = 2
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `security_group_rules`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `security_group_rules` (
  `created_at` DATETIME NULL DEFAULT NULL ,
  `updated_at` DATETIME NULL DEFAULT NULL ,
  `deleted_at` DATETIME NULL DEFAULT NULL ,
  `deleted` TINYINT(1) NULL DEFAULT NULL ,
  `id` INT(11) NOT NULL AUTO_INCREMENT ,
  `parent_group_id` INT(11) NULL DEFAULT NULL ,
  `protocol` VARCHAR(255) NULL DEFAULT NULL ,
  `from_port` INT(11) NULL DEFAULT NULL ,
  `to_port` INT(11) NULL DEFAULT NULL ,
  `cidr` VARCHAR(255) NULL DEFAULT NULL ,
  `group_id` INT(11) NULL DEFAULT NULL ,
  PRIMARY KEY (`id`) ,
  INDEX `parent_group_id` (`parent_group_id` ASC) ,
  INDEX `group_id` (`group_id` ASC) ,
  CONSTRAINT `security_group_rules_ibfk_1`
    FOREIGN KEY (`parent_group_id` )
    REFERENCES `security_groups` (`id` ),
  CONSTRAINT `security_group_rules_ibfk_2`
    FOREIGN KEY (`group_id` )
    REFERENCES `security_groups` (`id` ))
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `services`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `services` (
  `created_at` DATETIME NULL DEFAULT NULL ,
  `updated_at` DATETIME NULL DEFAULT NULL ,
  `deleted_at` DATETIME NULL DEFAULT NULL ,
  `deleted` TINYINT(1) NULL DEFAULT NULL ,
  `id` INT(11) NOT NULL AUTO_INCREMENT ,
  `host` VARCHAR(255) NULL DEFAULT NULL ,
  `binary` VARCHAR(255) NULL DEFAULT NULL ,
  `topic` VARCHAR(255) NULL DEFAULT NULL ,
  `report_count` INT(11) NOT NULL ,
  `disabled` TINYINT(1) NULL DEFAULT NULL ,
  `availability_zone` VARCHAR(255) NULL DEFAULT NULL ,
  PRIMARY KEY (`id`) )
ENGINE = InnoDB
AUTO_INCREMENT = 14
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `sm_flavors`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `sm_flavors` (
  `created_at` DATETIME NULL DEFAULT NULL ,
  `updated_at` DATETIME NULL DEFAULT NULL ,
  `deleted_at` DATETIME NULL DEFAULT NULL ,
  `deleted` TINYINT(1) NULL DEFAULT NULL ,
  `id` INT(11) NOT NULL AUTO_INCREMENT ,
  `label` VARCHAR(255) NULL DEFAULT NULL ,
  `description` VARCHAR(255) NULL DEFAULT NULL ,
  PRIMARY KEY (`id`) )
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `sm_backend_config`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `sm_backend_config` (
  `created_at` DATETIME NULL DEFAULT NULL ,
  `updated_at` DATETIME NULL DEFAULT NULL ,
  `deleted_at` DATETIME NULL DEFAULT NULL ,
  `deleted` TINYINT(1) NULL DEFAULT NULL ,
  `id` INT(11) NOT NULL AUTO_INCREMENT ,
  `flavor_id` INT(11) NOT NULL ,
  `sr_uuid` VARCHAR(255) NULL DEFAULT NULL ,
  `sr_type` VARCHAR(255) NULL DEFAULT NULL ,
  `config_params` VARCHAR(2047) NULL DEFAULT NULL ,
  PRIMARY KEY (`id`) ,
  INDEX `flavor_id` (`flavor_id` ASC) ,
  CONSTRAINT `sm_backend_config_ibfk_1`
    FOREIGN KEY (`flavor_id` )
    REFERENCES `sm_flavors` (`id` ))
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `sm_volume`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `sm_volume` (
  `created_at` DATETIME NULL DEFAULT NULL ,
  `updated_at` DATETIME NULL DEFAULT NULL ,
  `deleted_at` DATETIME NULL DEFAULT NULL ,
  `deleted` TINYINT(1) NULL DEFAULT NULL ,
  `id` INT(11) NOT NULL ,
  `backend_id` INT(11) NOT NULL ,
  `vdi_uuid` VARCHAR(255) NULL DEFAULT NULL ,
  PRIMARY KEY (`id`) ,
  INDEX `backend_id` (`backend_id` ASC) ,
  CONSTRAINT `sm_volume_ibfk_1`
    FOREIGN KEY (`id` )
    REFERENCES `volumes` (`id` ),
  CONSTRAINT `sm_volume_ibfk_2`
    FOREIGN KEY (`backend_id` )
    REFERENCES `sm_backend_config` (`id` ))
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `users`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `users` (
  `created_at` DATETIME NULL DEFAULT NULL ,
  `updated_at` DATETIME NULL DEFAULT NULL ,
  `deleted_at` DATETIME NULL DEFAULT NULL ,
  `deleted` TINYINT(1) NULL DEFAULT NULL ,
  `id` VARCHAR(255) NOT NULL ,
  `name` VARCHAR(255) NULL DEFAULT NULL ,
  `access_key` VARCHAR(255) NULL DEFAULT NULL ,
  `secret_key` VARCHAR(255) NULL DEFAULT NULL ,
  `is_admin` TINYINT(1) NULL DEFAULT NULL ,
  PRIMARY KEY (`id`) )
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `user_project_association`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `user_project_association` (
  `created_at` DATETIME NULL DEFAULT NULL ,
  `updated_at` DATETIME NULL DEFAULT NULL ,
  `deleted_at` DATETIME NULL DEFAULT NULL ,
  `deleted` TINYINT(1) NULL DEFAULT NULL ,
  `user_id` VARCHAR(255) NOT NULL ,
  `project_id` VARCHAR(255) NOT NULL ,
  PRIMARY KEY (`user_id`, `project_id`) ,
  INDEX `project_id` (`project_id` ASC) ,
  CONSTRAINT `user_project_association_ibfk_1`
    FOREIGN KEY (`user_id` )
    REFERENCES `users` (`id` ),
  CONSTRAINT `user_project_association_ibfk_2`
    FOREIGN KEY (`project_id` )
    REFERENCES `projects` (`id` ))
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `user_project_role_association`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `user_project_role_association` (
  `created_at` DATETIME NULL DEFAULT NULL ,
  `updated_at` DATETIME NULL DEFAULT NULL ,
  `deleted_at` DATETIME NULL DEFAULT NULL ,
  `deleted` TINYINT(1) NULL DEFAULT NULL ,
  `user_id` VARCHAR(255) NOT NULL ,
  `project_id` VARCHAR(255) NOT NULL ,
  `role` VARCHAR(255) NOT NULL ,
  PRIMARY KEY (`user_id`, `project_id`, `role`) ,
  CONSTRAINT `user_project_role_association_ibfk_1`
    FOREIGN KEY (`user_id` , `project_id` )
    REFERENCES `user_project_association` (`user_id` , `project_id` ))
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `user_role_association`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `user_role_association` (
  `created_at` DATETIME NULL DEFAULT NULL ,
  `updated_at` DATETIME NULL DEFAULT NULL ,
  `deleted_at` DATETIME NULL DEFAULT NULL ,
  `deleted` TINYINT(1) NULL DEFAULT NULL ,
  `user_id` VARCHAR(255) NOT NULL ,
  `role` VARCHAR(255) NOT NULL ,
  PRIMARY KEY (`user_id`, `role`) ,
  CONSTRAINT `user_role_association_ibfk_1`
    FOREIGN KEY (`user_id` )
    REFERENCES `users` (`id` ))
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `virtual_interfaces`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `virtual_interfaces` (
  `created_at` DATETIME NULL DEFAULT NULL ,
  `updated_at` DATETIME NULL DEFAULT NULL ,
  `deleted_at` DATETIME NULL DEFAULT NULL ,
  `deleted` TINYINT(1) NULL DEFAULT NULL ,
  `id` INT(11) NOT NULL AUTO_INCREMENT ,
  `address` VARCHAR(255) NULL DEFAULT NULL ,
  `network_id` INT(11) NULL DEFAULT NULL ,
  `instance_id` INT(11) NOT NULL ,
  `uuid` VARCHAR(36) NULL DEFAULT NULL ,
  PRIMARY KEY (`id`) ,
  UNIQUE INDEX `address` (`address` ASC) ,
  INDEX `network_id` (`network_id` ASC) ,
  INDEX `instance_id` (`instance_id` ASC) )
ENGINE = InnoDB
AUTO_INCREMENT = 3
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `virtual_storage_arrays`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `virtual_storage_arrays` (
  `created_at` DATETIME NULL DEFAULT NULL ,
  `updated_at` DATETIME NULL DEFAULT NULL ,
  `deleted_at` DATETIME NULL DEFAULT NULL ,
  `deleted` TINYINT(1) NULL DEFAULT NULL ,
  `id` INT(11) NOT NULL AUTO_INCREMENT ,
  `display_name` VARCHAR(255) NULL DEFAULT NULL ,
  `display_description` VARCHAR(255) NULL DEFAULT NULL ,
  `project_id` VARCHAR(255) NULL DEFAULT NULL ,
  `availability_zone` VARCHAR(255) NULL DEFAULT NULL ,
  `instance_type_id` INT(11) NOT NULL ,
  `image_ref` VARCHAR(255) NULL DEFAULT NULL ,
  `vc_count` INT(11) NOT NULL ,
  `vol_count` INT(11) NOT NULL ,
  `status` VARCHAR(255) NULL DEFAULT NULL ,
  PRIMARY KEY (`id`) )
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `volume_metadata`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `volume_metadata` (
  `created_at` DATETIME NULL DEFAULT NULL ,
  `updated_at` DATETIME NULL DEFAULT NULL ,
  `deleted_at` DATETIME NULL DEFAULT NULL ,
  `deleted` TINYINT(1) NULL DEFAULT NULL ,
  `id` INT(11) NOT NULL AUTO_INCREMENT ,
  `volume_id` INT(11) NOT NULL ,
  `key` VARCHAR(255) NULL DEFAULT NULL ,
  `value` VARCHAR(255) NULL DEFAULT NULL ,
  PRIMARY KEY (`id`) ,
  INDEX `volume_id` (`volume_id` ASC) ,
  CONSTRAINT `volume_metadata_ibfk_1`
    FOREIGN KEY (`volume_id` )
    REFERENCES `volumes` (`id` ))
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `volume_types`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `volume_types` (
  `created_at` DATETIME NULL DEFAULT NULL ,
  `updated_at` DATETIME NULL DEFAULT NULL ,
  `deleted_at` DATETIME NULL DEFAULT NULL ,
  `deleted` TINYINT(1) NULL DEFAULT NULL ,
  `id` INT(11) NOT NULL AUTO_INCREMENT ,
  `name` VARCHAR(255) NULL DEFAULT NULL ,
  PRIMARY KEY (`id`) )
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `volume_type_extra_specs`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `volume_type_extra_specs` (
  `created_at` DATETIME NULL DEFAULT NULL ,
  `updated_at` DATETIME NULL DEFAULT NULL ,
  `deleted_at` DATETIME NULL DEFAULT NULL ,
  `deleted` TINYINT(1) NULL DEFAULT NULL ,
  `id` INT(11) NOT NULL AUTO_INCREMENT ,
  `volume_type_id` INT(11) NOT NULL ,
  `key` VARCHAR(255) NULL DEFAULT NULL ,
  `value` VARCHAR(255) NULL DEFAULT NULL ,
  PRIMARY KEY (`id`) ,
  INDEX `volume_type_id` (`volume_type_id` ASC) ,
  CONSTRAINT `volume_type_extra_specs_ibfk_1`
    FOREIGN KEY (`volume_type_id` )
    REFERENCES `volume_types` (`id` ))
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;



SET SQL_MODE=@OLD_SQL_MODE;
SET FOREIGN_KEY_CHECKS=@OLD_FOREIGN_KEY_CHECKS;
SET UNIQUE_CHECKS=@OLD_UNIQUE_CHECKS;
